@@ -18,6 +18,10 @@ package Image::BMP;
 # CHANGELOG
 # ---------
 #
+# Version 1.24 2024/02/05
+# -----------------------
+# * Close 'bug' requesting update from indirect object creation to new method
+#
 # Version 1.23 2024/02/05
 # -----------------------
 # * Add tests and a CHANGELOG to be super professional and fancy
@@ -74,7 +78,7 @@ use Exporter ();
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(open_file open_pipe close load colormap xy xy_rgb xy_index set save view_ascii debug remember_image ignore_imagemagick_bug add_pixel file);
 
-$VERSION = '1.23';
+$VERSION = '1.24';
 $LIBRARY = __PACKAGE__;
 
 ##################################################
@@ -157,7 +161,7 @@ sub open_file($$) {
 	my ($bmp,$file) = @_;
 	$file = $file || $bmp->{file};
 	$bmp->_debug(1,"BMP: $file\n");
-	$bmp->{fh} = new IO::File;
+	$bmp->{fh} = IO::File->new();
 	$bmp->{file} = $file;
 
 	# Avoid using open unless we need it.  Bit kludgy.  Unnecessary??
@@ -255,7 +259,7 @@ sub write_file($$) {
 	$wfile = $wfile || $bmp->{wfile};
 	return unless $wfile;
 	$bmp->{wfile} = $wfile;
-	$bmp->{wfh} = new IO::File;
+	$bmp->{wfh} = IO::File->new();
 	sysopen($bmp->{wfh},$bmp->{wfile},O_WRONLY|O_CREAT)
 		|| fatal("Couldn't write file: $wfile");
 }
